Permutation Invariat Vector (PIV)
====================================


Install
------------------------------------
Enable compilation by adding the `--enable-modules=+piv`
to the configure command.


Documentation
------------------------------------
See the generated documentation for information on
using


Authors
------------------------------------
Silvio Pipolo (University of Lille) <silvio.pipolo@univ-lille.fr>
Fabio Pietrucci (Sorbonne University, Paris) <fabio.pietrucci@impmc.upmc.fr>


Copyright
------------------------------------
See ./COPYRIGHT
